@@ -1,5 +1,5 @@
 package XML::RSS::Private::Output::Base;
-$XML::RSS::Private::Output::Base::VERSION = '1.61';
+$XML::RSS::Private::Output::Base::VERSION = '1.62';
 use strict;
 use warnings;
 
@@ -1149,9 +1149,11 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 VERSION
 
-version 1.61
+version 1.62
 
 =head1 METHODS
 
@@ -1171,36 +1173,10 @@ Internal use.
 
 Internal use.
 
-=head1 AUTHOR
-
-Shlomi Fish <shlomif@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2001 by Various.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website
-L<https://github.com/shlomif/perl-XML-RSS/issues>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
-=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+=for :stopwords cpan testmatrix url bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
 
 =head1 SUPPORT
 
-=head2 Perldoc
-
-You can find documentation for this module with the perldoc command.
-
-  perldoc XML::RSS::Private::Output::Base
-
 =head2 Websites
 
 The following websites have more information about this module, and may be of help to you. As always,
@@ -1218,14 +1194,6 @@ L<https://metacpan.org/release/XML-RSS>
 
 =item *
 
-Search CPAN
-
-The default CPAN search engine, useful to view POD in HTML format.
-
-L<http://search.cpan.org/dist/XML-RSS>
-
-=item *
-
 RT: CPAN's Bug Tracker
 
 The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
@@ -1234,22 +1202,6 @@ L<https://rt.cpan.org/Public/Dist/Display.html?Name=XML-RSS>
 
 =item *
 
-AnnoCPAN
-
-The AnnoCPAN is a website that allows community annotations of Perl module documentation.
-
-L<http://annocpan.org/dist/XML-RSS>
-
-=item *
-
-CPAN Ratings
-
-The CPAN Ratings is a website that allows community ratings and reviews of Perl modules.
-
-L<http://cpanratings.perl.org/d/XML-RSS>
-
-=item *
-
 CPANTS
 
 The CPANTS is a website that analyzes the Kwalitee ( code metrics ) of a distribution.
@@ -1298,4 +1250,24 @@ L<https://github.com/shlomif/perl-XML-RSS>
 
   git clone git://github.com/shlomif/perl-XML-RSS.git
 
+=head1 AUTHOR
+
+Shlomi Fish <shlomif@cpan.org>
+
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/shlomif/perl-XML-RSS/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2001 by Various.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =cut
